@@ -12,6 +12,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import time
+
 from oslo_config import cfg
 import yaml
 
@@ -23,10 +25,9 @@ CONF = cfg.CONF
 
 
 class VnfdTestCreate(base.BaseTackerTest):
-    def _test_create_list_delete_tosca_vnfd(self, tosca_vnfd_file):
+    def _test_create_list_delete_tosca_vnfd(self, tosca_vnfd_file, vnfd_name):
         input_yaml = read_file(tosca_vnfd_file)
         tosca_dict = yaml.safe_load(input_yaml)
-        vnfd_name = 'sample-tosca-vnfd'
         tosca_arg = {'vnfd': {'name': vnfd_name,
                               'attributes': {'vnfd': tosca_dict}}}
         vnfd_instance = self.client.create_vnfd(body=tosca_arg)
@@ -38,17 +39,27 @@ class VnfdTestCreate(base.BaseTackerTest):
         vnfd_id = vnfd_instance['vnfd']['id']
         self.verify_vnfd_events(
             vnfd_id, evt_constants.RES_EVT_CREATE,
-            vnfd_instance['vnfd'][evt_constants.RES_EVT_CREATED_FLD])
+            evt_constants.RES_EVT_ONBOARDED)
 
         try:
             self.client.delete_vnfd(vnfd_id)
         except Exception:
             assert False, "vnfd Delete failed"
-        self.verify_vnfd_events(vnfd_id, evt_constants.RES_EVT_DELETE)
+        self.verify_vnfd_events(vnfd_id, evt_constants.RES_EVT_DELETE,
+                                evt_constants.RES_EVT_NA_STATE)
 
     def test_tosca_vnfd(self):
-        self._test_create_list_delete_tosca_vnfd('sample-tosca-vnfd.yaml')
+        self._test_create_list_delete_tosca_vnfd('sample-tosca-vnfd.yaml',
+                                                 'sample-tosca-vnfd-template')
 
     def test_tosca_large_vnfd(self):
         self._test_create_list_delete_tosca_vnfd(
-            'sample-tosca-vnfd-large-template.yaml')
+            'sample-tosca-vnfd-large-template.yaml',
+            'sample-tosca-vnfd-large-template')
+
+    def test_tosca_re_create_delete_vnfd(self):
+        self._test_create_list_delete_tosca_vnfd('sample-tosca-vnfd.yaml',
+                                                 'test_vnfd')
+        time.sleep(1)
+        self._test_create_list_delete_tosca_vnfd('sample-tosca-vnfd.yaml',
+                                                 'test_vnfd')
