@@ -30,6 +30,7 @@ def _get_template(name):
     return f.read()
 
 tosca_vnfd_openwrt = _get_template('test_tosca_openwrt.yaml')
+tosca_invalid_vnfd = _get_template('test_tosca_parser_failure.yaml')
 config_data = _get_template('config_data.yaml')
 update_config_data = _get_template('update_config_data.yaml')
 vnffg_params = _get_template('vnffg_params.yaml')
@@ -63,6 +64,8 @@ vnfd_alarm_multi_actions_tosca_template = _get_template(
 nsd_tosca_template = yaml.safe_load(_get_template('tosca_nsd_template.yaml'))
 vnffgd_wrong_cp_number_template = yaml.safe_load(_get_template(
     'tosca_vnffgd_wrong_cp_number_template.yaml'))
+vnfd_instance_reservation_alarm_scale_tosca_template = _get_template(
+    'test_tosca-vnfd-instance-reservation.yaml')
 
 
 def get_dummy_vnfd_obj():
@@ -77,6 +80,18 @@ def get_dummy_vnfd_obj():
                 u'username': u'admin', u'password': u'devstack'}}}}
 
 
+def get_invalid_vnfd_obj():
+    return {u'vnfd': {u'service_types': [{u'service_type': u'vnfd'}],
+                      'name': 'dummy_vnfd',
+                      'tenant_id': u'ad7ebc56538745a08ef7c5e97f8bd437',
+                      u'attributes': {u'vnfd': yaml.safe_load(
+                          tosca_invalid_vnfd)},
+                      'description': 'dummy_vnfd_description',
+                      'template_source': 'onboarded',
+            u'auth': {u'tenantName': u'admin', u'passwordCredentials': {
+                u'username': u'admin', u'password': u'devstack'}}}}
+
+
 def get_dummy_vnfd_obj_inline():
     return {u'vnfd': {u'service_types': [{u'service_type': u'vnfd'}],
                       'name': 'tmpl-koeak4tqgoqo8cr4-dummy_inline_vnf',
@@ -114,8 +129,9 @@ def get_dummy_vnf_config_obj():
         'config': {'firewall': 'dummy_firewall_values'}}}}}}}
 
 
-def get_dummy_device_obj():
-    return {'status': 'PENDING_CREATE', 'instance_id': None, 'name':
+def get_dummy_vnf(status='PENDING_CREATE', scaling_group=False,
+                  instance_id=None):
+    dummy_vnf = {'status': status, 'instance_id': instance_id, 'name':
         u'test_openwrt', 'tenant_id': u'ad7ebc56538745a08ef7c5e97f8bd437',
         'vnfd_id': u'eb094833-995e-49f0-a047-dfb56aaf7c4e',
         'vnfd': {
@@ -127,10 +143,15 @@ def get_dummy_device_obj():
             'attributes': {u'vnfd': tosca_vnfd_openwrt},
             'id': u'fb048660-dc1b-4f0f-bd89-b023666650ec',
             'name': u'openwrt_services'},
-        'mgmt_url': None, 'service_context': [],
+        'mgmt_ip_address': None, 'service_context': [],
         'attributes': {u'param_values': u''},
         'id': 'eb84260e-5ff7-4332-b032-50a14d6c1123',
         'description': u'OpenWRT with services'}
+    if scaling_group:
+        dummy_vnf['attributes'].update({'scaling_group_names':
+                                   '{"SP1": "SP1_group"}',
+                                   'heat_template': 'test'})
+    return dummy_vnf
 
 
 def get_dummy_vnf_config_attr():
@@ -144,7 +165,8 @@ def get_dummy_vnf_config_attr():
             'mgmt_driver': u'openwrt',
             'attributes': {u'vnfd': tosca_vnfd_openwrt},
             'id': u'fb048660-dc1b-4f0f-bd89-b023666650ec', 'name':
-            u'openwrt_services'}, 'mgmt_url': None, 'service_context': [],
+            u'openwrt_services'}, 'mgmt_ip_address': None,
+            'service_context': [],
             'attributes': {u'config': config_data},
             'id': 'eb84260e-5ff7-4332-b032-50a14d6c1123',
             'description': u'OpenWRT with services'}
@@ -155,7 +177,8 @@ def get_dummy_vnf_update_config():
 
 
 def get_vim_obj():
-    return {'vim': {'type': 'openstack', 'auth_url': 'http://localhost:5000',
+    return {'vim': {'type': 'openstack',
+                    'auth_url': 'http://localhost/identity',
                     'vim_project': {'name': 'test_project'},
                     'auth_cred': {'username': 'test_user',
                                   'password': 'test_password',
@@ -170,7 +193,7 @@ def get_vim_auth_obj():
             'project_id': None,
             'project_name': 'test_project',
             'cert_verify': 'True',
-            'auth_url': 'http://localhost:5000/v3',
+            'auth_url': 'http://localhost/identity/v3',
             'user_domain_name': 'default',
             'project_domain_name': 'default'}
 
