@@ -59,6 +59,11 @@ class FakeNeutronClient(mock.Mock):
         self.__pp_dict[pp_id] = port_pair
         return pp_id
 
+    def port_pair_list(self):
+        pp = {'port_pairs': [{'ingress': 'abc',
+                              'egress': 'xyz'}]}
+        return pp
+
     def show_port_pair(self, port_pair_dict):
         input_pp_name = port_pair_dict['name']
         for pp_id in self.__pp_dict:
@@ -73,6 +78,10 @@ class FakeNeutronClient(mock.Mock):
         self.__ppg_dict[ppg_id] = port_pair_group
         return ppg_id
 
+    def port_pair_group_list(self):
+        value = {'port_pair_groups': []}
+        return value
+
     def show_port_pair_group(self, port_pair_group_dict):
         input_ppg_name = port_pair_group_dict['name']
         for ppg_id in self.__ppg_dict:
@@ -100,6 +109,11 @@ class FakeNeutronClient(mock.Mock):
             raise ValueError('port chain delete failed')
         self.__chain_dict.pop(chain_id)
 
+    def port_chain_list(self):
+        pc = {'port_chains': [{'port_pair_groups': ['random_id1',
+                                                    'random_id2']}]}
+        return pc
+
 
 class TestChainSFC(base.TestCase):
 
@@ -169,6 +183,7 @@ class TestChainSFC(base.TestCase):
         vnfs = [vnf_1, vnf_2, vnf_3]
 
         chain_id = self.sfc_driver.create_chain(name='fake_ffg',
+                                                path_id=None,
                                                 fc_ids=fc_id,
                                                 vnfs=vnfs,
                                                 auth_attr=auth_attr)
@@ -224,6 +239,7 @@ class TestChainSFC(base.TestCase):
         vnfs = [vnf_1, vnf_2, vnf_3]
 
         result = self.sfc_driver.create_chain(name='fake_ffg',
+                                              path_id=None,
                                               fc_ids=fc_id,
                                               vnfs=vnfs,
                                               auth_attr=auth_attr)
@@ -255,6 +271,7 @@ class TestChainSFC(base.TestCase):
         vnfs = [vnf_1, vnf_2, vnf_3]
 
         chain_id = self.sfc_driver.create_chain(name='fake_ffg',
+                                                path_id=None,
                                                 fc_ids=fc_id,
                                                 vnfs=vnfs,
                                                 auth_attr=auth_attr)
