@@ -17,6 +17,7 @@ import os
 import testtools
 import yaml
 
+from tacker.extensions import vnfm
 from tacker.tosca import utils as toscautils
 from toscaparser import tosca_template
 from translator.hot import tosca_translator
@@ -34,12 +35,12 @@ class TestToscaUtils(testtools.TestCase):
     tosca_openwrt = _get_template('test_tosca_openwrt.yaml')
     vnfd_dict = yaml.safe_load(tosca_openwrt)
     toscautils.updateimports(vnfd_dict)
-    tosca = tosca_template.ToscaTemplate(parsed_params={}, a_file=False,
-                          yaml_dict_tpl=vnfd_dict)
-    tosca_flavor = _get_template('test_tosca_flavor.yaml')
 
     def setUp(self):
         super(TestToscaUtils, self).setUp()
+        self.tosca = tosca_template.ToscaTemplate(
+            parsed_params={}, a_file=False, yaml_dict_tpl=self.vnfd_dict)
+        self.tosca_flavor = _get_template('test_tosca_flavor.yaml')
 
     def test_updateimport(self):
         importspath = os.path.abspath('./tacker/tosca/lib/')
@@ -71,35 +72,54 @@ class TestToscaUtils(testtools.TestCase):
         self.assertEqual(expected_mgmt_ports, mgmt_ports)
 
     def test_post_process_template(self):
-        tosca2 = tosca_template.ToscaTemplate(parsed_params={}, a_file=False,
-                          yaml_dict_tpl=self.vnfd_dict)
-        toscautils.post_process_template(tosca2)
+        tosca_post_process_tpl = _get_template(
+            'test_tosca_post_process_template.yaml')
+        vnfd_dict = yaml.safe_load(tosca_post_process_tpl)
+        toscautils.updateimports(vnfd_dict)
+        tosca = tosca_template.ToscaTemplate(parsed_params={}, a_file=False,
+                                             yaml_dict_tpl=vnfd_dict)
+        toscautils.post_process_template(tosca)
+
         invalidNodes = 0
-        for nt in tosca2.nodetemplates:
+        deletedProperties = 0
+        convertedValues = 0
+        convertedProperties = 0
+
+        for nt in tosca.nodetemplates:
             if (nt.type_definition.is_derived_from(toscautils.MONITORING) or
-                nt.type_definition.is_derived_from(toscautils.FAILURE) or
+                    nt.type_definition.is_derived_from(toscautils.FAILURE) or
                     nt.type_definition.is_derived_from(toscautils.PLACEMENT)):
                 invalidNodes += 1
 
+            if nt.type in toscautils.delpropmap.keys():
+                for prop in toscautils.delpropmap[nt.type]:
+                    for p in nt.get_properties_objects():
+                        if prop == p.name:
+                            deletedProperties += 1
+
+            if nt.type in toscautils.convert_prop_values:
+                for prop in toscautils.convert_prop_values[nt.type].keys():
+                    convertmap = toscautils.convert_prop_values[nt.type][prop]
+                    for p in nt.get_properties_objects():
+                        if (prop == p.name and
+                                p.value in convertmap.keys()):
+                            convertedValues += 1
+
+            if nt.type in toscautils.convert_prop:
+                for prop in toscautils.convert_prop[nt.type].keys():
+                    for p in nt.get_properties_objects():
+                        if prop == p.name:
+                            convertedProperties += 1
+
+            if nt.name == 'VDU1':
+                vdu1_hints = nt.get_properties().get('scheduler_hints')
+                vdu1_rsv = vdu1_hints.value.get('reservation')
+
         self.assertEqual(0, invalidNodes)
-
-        deletedProperties = 0
-        if nt.type in toscautils.delpropmap.keys():
-            for prop in toscautils.delpropmap[nt.type]:
-                for p in nt.get_properties_objects():
-                    if prop == p.name:
-                        deletedProperties += 1
-
         self.assertEqual(0, deletedProperties)
-
-        convertedProperties = 0
-        if nt.type in toscautils.convert_prop:
-            for prop in toscautils.convert_prop[nt.type].keys():
-                for p in nt.get_properties_objects():
-                    if prop == p.name:
-                        convertedProperties += 1
-
+        self.assertEqual(0, convertedValues)
         self.assertEqual(0, convertedProperties)
+        self.assertEqual(vdu1_rsv, '459e94c9-efcd-4320-abf5-8c18cd82c331')
 
     def test_post_process_heat_template(self):
         tosca1 = tosca_template.ToscaTemplate(parsed_params={}, a_file=False,
@@ -179,6 +199,18 @@ class TestToscaUtils(testtools.TestCase):
         actual_flavor_dict = toscautils.get_flavor_dict(tosca)
         self.assertEqual(expected_flavor_dict, actual_flavor_dict)
 
+    def test_get_flavor_dict_with_wrong_cpu(self):
+        tosca_fes = _get_template(
+            'tosca_flavor_with_wrong_cpu.yaml')
+        vnfd_dict = yaml.safe_load(tosca_fes)
+        toscautils.updateimports(vnfd_dict)
+        tosca = tosca_template.ToscaTemplate(a_file=False,
+                                             yaml_dict_tpl=vnfd_dict)
+
+        self.assertRaises(vnfm.CpuAllocationInvalidValues,
+                          toscautils.get_flavor_dict,
+                          tosca)
+
     def test_tacker_conf_heat_extra_specs_all_numa_count(self):
         tosca_fes_all_numa_count = _get_template(
             'tosca_flavor_all_numa_count.yaml')
@@ -253,7 +285,7 @@ class TestToscaUtils(testtools.TestCase):
         expected_dict = {
             'volumes': {
                 'VB1': {
-                    'image': 'cirros-0.3.5-x86_64-disk',
+                    'image': 'cirros-0.4.0-x86_64-disk',
                     'size': '1'
                 }
             },
